@@ -1,11 +1,13 @@
 """
 PyLEMS utility classes / functions
 
-@author: Gautham Ganapathy
-@organization: LEMS (http://neuroml.org/lems/, https://github.com/organizations/LEMS)
-@contact: gautham@lisphacker.org
+:author: Gautham Ganapathy
+:organization: LEMS (https://github.com/organizations/LEMS)
 """
 
+from lems import __schema_location__
+
+
 id_counter = 0
 
 def make_id():
@@ -17,11 +19,11 @@ def merge_maps(m, base):
     """
     Merge in undefined map entries from given map.
     
-    @param m: Map to be merged into.
-    @type m: lems.util.Map
+    :param m: Map to be merged into.
+    :type m: lems.util.Map
     
-    @param base: Map to be merged into.
-    @type base: lems.util.Map
+    :param base: Map to be merged into.
+    :type base: lems.util.Map
     """
     
     for k in base.keys():
@@ -32,11 +34,11 @@ def merge_lists(l, base):
     """
     Merge in undefined list entries from given list.
     
-    @param l: List to be merged into.
-    @type l: list
+    :param l: List to be merged into.
+    :type l: list
     
-    @param base: List to be merged into.
-    @type base: list
+    :param base: List to be merged into.
+    :type base: list
     """
     
     for i in base:
@@ -52,7 +54,7 @@ def validate_lems(file_name):
     except:
         from urllib.request import urlopen # Python 3
         
-    schema_file = urlopen("https://raw.githubusercontent.com/LEMS/LEMS/development/Schemas/LEMS/LEMS_v0.7.3.xsd")
+    schema_file = urlopen(__schema_location__)
     xmlschema = etree.XMLSchema(etree.parse(schema_file))
     print("Validating {0} against {1}".format(file_name, schema_file.geturl()))
     xmlschema.assertValid(etree.parse(file_name))
