@@ -1,9 +1,8 @@
 """
 Base class for runnable components.
 
-@author: Gautham Ganapathy
-@organization: LEMS (http://neuroml.org/lems/, https://github.com/organizations/LEMS)
-@contact: gautham@lisphacker.org
+:author: Gautham Ganapathy
+:organization: LEMS (https://github.com/organizations/LEMS)
 """
 
 from lems.base.base import LEMSBase
@@ -181,8 +180,15 @@ class Runnable(Reflective):
     def add_child_to_group(self, group_name, child):
         #print("add_child_to_group in %s; grp: %s; child: %s "%(self.id, group_name, child))
         if group_name not in self.__dict__:
+            #print sorted(self.__dict__.keys())
             self.__dict__[group_name] = []
             self.groups.append(group_name)
+        #print sorted(self.__dict__.keys())
+        #print ".........."
+        #print self.__dict__[group_name]
+        # Force group_name attribute to be a list before we append to it.
+        if type(self.__dict__[group_name]) is not list:
+            self.__dict__[group_name] = [self.__dict__[group_name]]
         self.__dict__[group_name].append(child)
         child.parent = self
 
@@ -303,16 +309,25 @@ class Runnable(Reflective):
                 return childobj.resolve_path(new_path)
 
     def add_variable_recorder(self, data_output, recorder):
-        self.add_variable_recorder2(data_output, recorder, recorder.quantity)
+        self.add_variable_recorder2(data_output, recorder, recorder.quantity, recorder.quantity)
 
-    def add_variable_recorder2(self, data_output, recorder, path):
+    def add_variable_recorder2(self, data_output, recorder, path, full_path):
+        
         if path[0] == '/':
-            self.parent.add_variable_recorder2(data_output, recorder, path)
+            self.parent.add_variable_recorder2(data_output, recorder, path, full_path)
         elif path.find('../') == 0:
-            self.parent.add_variable_recorder2(data_output, recorder, path[3:])
+            self.parent.add_variable_recorder2(data_output, recorder, path[3:], full_path)
         elif path.find('/') >= 1:
             (child, new_path) = path.split('/', 1)
-
+            
+            if ':' in child:
+                syn_parts = child.split(":")
+                if syn_parts[0] == 'synapses' and syn_parts[2] == '0':
+                    child = syn_parts[1]
+                else:
+                    raise SimBuildError('Cannot determine what to do with (synapse?) path: %s (full path: %s)'
+                                        % (child, full_path))
+                
             idxbegin = child.find('[')
             idxend = child.find(']')
             if idxbegin != 0 and idxend > idxbegin:
@@ -326,11 +341,13 @@ class Runnable(Reflective):
                 if idx == -1:
                     childobj.add_variable_recorder2(data_output,
                                                     recorder,
-                                                    new_path)
+                                                    new_path,
+                                                    full_path)
                 else:
                     childobj.array[idx].add_variable_recorder2(data_output,
                                                                recorder,
-                                                               new_path)
+                                                               new_path,
+                                                               full_path)
             elif child in self.component.children:
                 cdef = self.component.children[child]
                 childobj = None
@@ -343,13 +360,13 @@ class Runnable(Reflective):
                                                     recorder,
                                                     new_path)
                 else:                    
-                    raise SimBuildError('Unable to find child \'{0}\' in '
+                    raise SimBuildError('Unable to find the child \'{0}\' in '
                                         '\'{1}\''.format(child, self.id))
             else:
-                raise SimBuildError('Unable to find child \'{0}\' in '
+                raise SimBuildError('Unable to find a child \'{0}\' in '
                                     '\'{1}\''.format(child, self.id))
         else:
-            self.recorded_variables.append(Recording(path, data_output, recorder))
+            self.recorded_variables.append(Recording(path, full_path, data_output, recorder))
 
 
     def configure_time(self, time_step, time_total):
@@ -580,8 +597,8 @@ class Runnable(Reflective):
         """
         Make a copy of this runnable.
 
-        @return: Copy of this runnable.
-        @rtype: lems.sim.runnable.Runnable
+        :return: Copy of this runnable.
+        :rtype: lems.sim.runnable.Runnable
         """
         if self.debug: print("Coping....."+self.id)
         r = Runnable(self.id, self.component, self.parent)
